@@ -1,17 +1,17 @@
 import pickle
 
+from unittest import TestCase
+
+from actionpack.action import Result
 from actionpack.actions import Call
 from actionpack.utils import Closure
 from actionpack.utils import pickleable
 
-from oslash import Right
-from unittest import TestCase
-
 
 class CallTest(TestCase):
 
     @classmethod
-    def function(*args, **kwargs):
+    def function(*args, **kwargs) -> tuple:
         return args[1:], kwargs
 
     def setUp(self):
@@ -22,7 +22,7 @@ class CallTest(TestCase):
 
     def test_can_Call(self):
         result = self.action.perform()
-        self.assertIsInstance(result, Right)
+        self.assertIsInstance(result, Result)
         self.assertEqual(result.value, ((self.arg,), {self.kwarg: self.kwarg}))
 
     def test_can_pickle(self):
@@ -31,4 +31,3 @@ class CallTest(TestCase):
 
         self.assertTrue(pickleable(self.action))
         self.assertEqual(unpickled.__dict__, self.action.__dict__)
-
